/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2025 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.20.0.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Silicon Labs GG12 Thunderboard Kit.
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "em_device.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT      (12u)  // User LED UIF_LED0R, active high, Port pin A12
#define LED1_BIT      (13u)  // User LED UIF_LED0G, active high, Port pin A13
#define LED2_BIT      (14u)  // User LED UIF_LED0B, active high, Port pin A14
#define LEDMASK_ALL   ((1u << LED0_BIT) | (1u << LED1_BIT) | (1u << LED2_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO_TypeDef *gpio = GPIO;
  uint32_t     gpiomode;
  unsigned int Data;
  //
  // Enable GPIO
  //
  CMU->HFPERCLKEN0 |= CMU_CTRL_HFPERCLKEN;
  CMU->HFBUSCLKEN0 |= CMU_HFBUSCLKEN0_GPIO;
  //
  // Configure GPIO port A12-14 as LED control outputs
  //
  gpiomode  = GPIO->P[0].MODEH;
  gpiomode &= ~(_GPIO_P_MODEH_MODE12_MASK |
                _GPIO_P_MODEH_MODE13_MASK |
                _GPIO_P_MODEH_MODE14_MASK);
  gpiomode |= GPIO_P_MODEH_MODE10_PUSHPULL;
  gpiomode |= GPIO_P_MODEH_MODE11_PUSHPULL;
  gpiomode |= GPIO_P_MODEH_MODE12_PUSHPULL;
  gpio->P[0].MODEH = gpiomode;

  // Initially all LEDS off
  Data  = GPIO->P[0].DOUT;
  Data |= (LEDMASK_ALL);
  GPIO->P[0].DOUT = Data;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < 3) {
    GPIO->P[0].DOUT &= ~(1u << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < 3) {
    GPIO->P[0].DOUT |= (1u << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < 3) {
    if (GPIO->P[0].DOUT & (1u << (LED0_BIT + Index))) {
      GPIO->P[0].DOUT &= ~(1u << (LED0_BIT + Index));
    } else {
      GPIO->P[0].DOUT |=  (1u << (LED0_BIT + Index));
    }
  }
}

/****** End Of File *************************************************/
