/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2025 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS-Ultra * Real time operating system                     *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.20.0.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for TI LP-CC1312-R7 and TI LAUNCHXL-CC1312R1
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS        (2)
#define LED0_BIT        (6)  // DIO6, Red
#define LED1_BIT        (7)  // DIO7, Green

#define GPIO_BASE_ADDR  ((unsigned int)(0x40022000u))
#define GPIO_DOUTSET    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x090u))  // Data out set
#define GPIO_DOUTCLR    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x0A0u))  // Data out clear
#define GPIO_DOUTTGL    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x0B0u))  // Data out toggle
#define GPIO_DOE        (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x0D0u))  // Data output enable

#define IOC_BASE_ADDR   ((unsigned int)(0x40081000u))
#define IOC_IOCFG6      (*(volatile unsigned int*)(IOC_BASE_ADDR  + 0x018u))  // DIO6 configuration
#define IOC_IOCFG7      (*(volatile unsigned int*)(IOC_BASE_ADDR  + 0x01Cu))  // DIO7 configuration

#define PRCM_BASE_ADDR  ((unsigned int)(0x40082000u))
#define PRCM_GPIOCLKGR  (*(volatile unsigned int*)(PRCM_BASE_ADDR + 0x048u))  // GPIO Clock Gate
#define PRCM_PDCTL0     (*(volatile unsigned int*)(PRCM_BASE_ADDR + 0x12Cu))  // Power Domain Control

#define WDT_NOBUF       (*(volatile unsigned int*)(0x60082028u))              // WDT, non-buffered access

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  volatile int i;

  PRCM_PDCTL0    |= (1u << 2);         // Power up peripheral power domain (PRCM_PDCTL0.PERIPH_ON is bit[2])
  PRCM_GPIOCLKGR |= (1u);              // Enable clock for GPIO (PRCM_GPIOCLKGR.CLE_EN is bit[0])
  WDT_NOBUF      |= (1u);              // Handle watch dog
  for (i = 0; i < 1000; i++);          // Spend some time idling for above statement to take effect
  IOC_IOCFG6     &= ~0x63u;            // Select General purpose IO for DIO6 (IOCFG6.PORT_ID is bit[0..5])
  IOC_IOCFG6     &= ~(1u << 29);       // Disable input on DIO6 (IOCFG6.IE is bit[29])
  GPIO_DOE       |= (1u << LED0_BIT);  // Enable output on DIO6 (DOE.DIO6 is bit[6])
  IOC_IOCFG7     &= ~0x63u;            // Select General purpose IO for DIO7 (IOCFG7.PORT_ID is bit[0..5])
  IOC_IOCFG7     &= ~(1u << 29);       // Disable input on DIO7 (IOCFG7.IE is bit[29])
  GPIO_DOE       |= (1u << LED1_BIT);  // Enable output on DIO7 (DOE.DIO7 is bit[7])
  GPIO_DOUTCLR   |= (1u << LED0_BIT)
                 |  (1u << LED1_BIT);  // Initially, clear LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIO_DOUTSET = (1u << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIO_DOUTCLR = (1u << (LED0_BIT + Index));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIO_DOUTTGL = (1u << (LED0_BIT + Index));
  }
}

/****** End Of File *************************************************/
